aboutsummaryrefslogtreecommitdiffstats
path: root/examples/charts/memoryusage.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/charts/memoryusage.py')
-rw-r--r--examples/charts/memoryusage.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/charts/memoryusage.py b/examples/charts/memoryusage.py
index 4954b9cd7..9d7a99311 100644
--- a/examples/charts/memoryusage.py
+++ b/examples/charts/memoryusage.py
@@ -39,13 +39,13 @@
##
#############################################################################
"""PySide2 Charts example: Simple memory usage viewer"""
import os
import sys
-from PySide2.QtCore import QProcess
-from PySide2.QtWidgets import QApplication, QMainWindow
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import QProcess
+from PySide6.QtWidgets import QApplication, QMainWindow
+from PySide6.QtCharts import QtCharts
def runProcess(command, arguments):
process = QProcess()
@@ -39,13 +39,13 @@
##
#############################################################################
-"""PySide2 Charts example: Simple memory usage viewer"""
+"""PySide6 Charts example: Simple memory usage viewer"""
import os
import sys